summaryrefslogtreecommitdiffstats
path: root/kmail/kmfoldermgr.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmail/kmfoldermgr.h')
-rw-r--r--kmail/kmfoldermgr.h15
1 files changed, 8 insertions, 7 deletions
diff --git a/kmail/kmfoldermgr.h b/kmail/kmfoldermgr.h
index 587d8525..7e6e630d 100644
--- a/kmail/kmfoldermgr.h
+++ b/kmail/kmfoldermgr.h
@@ -13,9 +13,10 @@
class KMFolder;
-class KMFolderMgr: public QObject
+class KMFolderMgr: public TQObject
{
Q_OBJECT
+ TQ_OBJECT
public:
KMFolderMgr(const TQString& basePath, KMFolderDirType dirType = KMStandardDir);
@@ -32,13 +33,13 @@ public:
/** Searches folder and returns it. Skips directories
(objects of type KMFolderDir) if foldersOnly is TRUE. */
- virtual KMFolder* find(const TQString& folderName, bool foldersOnly=TRUE);
+ virtual KMFolder* tqfind(const TQString& folderName, bool foldersOnly=TRUE);
/** Searches for a folder with the given id, recurses into directories */
virtual KMFolder* findIdString(const TQString& folderId,
const uint id = 0, KMFolderDir *dir = 0);
/** Uses find() to find given folder. If not found the folder is
* created. Directories are skipped.
* If an id is passed this searches for it
*/
@@ -50,10 +51,10 @@ public:
virtual KMFolder* findById(const uint id);
virtual void getFolderURLS( TQStringList& flist,
- const TQString& prefix=TQString::null,
+ const TQString& prefix=TQString(),
KMFolderDir *adir=0 );
virtual KMFolder* getFolderByURL( const TQString& vpath,
- const TQString& prefix=TQString::null,
+ const TQString& prefix=TQString(),
KMFolderDir *adir=0 );
/** Create a mail folder in the root folder directory dir()
@@ -121,8 +122,8 @@ public:
/** Copy a folder */
void copyFolder( KMFolder* folder, KMFolderDir* newParent );
- /** Returns the parent Folder for the given folder or 0 on failure. */
- KMFolder* parentFolder( KMFolder* folder );
+ /** Returns the tqparent Folder for the given folder or 0 on failure. */
+ KMFolder* tqparentFolder( KMFolder* folder );
public slots:
/** GUI action: compact all folders that need to be compacted */
@@ -32,13 +33,13 @@ public:
virtual KMFolder* findIdString(const TQString& folderId,
const uint id = 0, KMFolderDir *dir = 0);
- /** Uses find() to find given folder. If not found the folder is
+ /** Uses tqfind() to find given folder. If not found the folder is
* created. Directories are skipped.
* If an id is passed this searches for it